package com.book.server.controller;

import com.book.dao.VO.OrderVo;
import com.book.dao.VO.WxPayInfo;
import com.book.dao.VO.WxPayRequest;
import com.book.server.common.entity.Result;
import com.book.server.common.entity.ResultCode;
import com.book.server.service.WxPayService;
import com.book.server.utils.NetworkUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;

/**
 * 支付
 * created in 2021/8/30
 * Project: book-store
 *
 * @author win7
 */
@RestController
@RequestMapping("/api/wxpay")
@Slf4j
public class WxPayController extends BaseController {
    @Autowired
    private WxPayService wxPayService;

    /**
     * 创建订单
     *
     * @param wxPayRequest
     * @return
     */
    @PostMapping("/createOrder")
    public Result<WxPayInfo> createOrder(@RequestBody WxPayRequest wxPayRequest, HttpServletRequest request) {
        String ip = null;
        try {
            ip = NetworkUtil.getIpAddress(request);
        } catch (IOException e) {
            e.printStackTrace();
        }
        wxPayRequest.setIp(ip);
        Result<WxPayInfo> success = Result.byObject(wxPayService.createOrder(wxPayRequest), ResultCode.ORDER_FAIL);
        return success;

    }

    /**
     * 通知
     *
     * @param request
     * @return
     */
    @PostMapping("/notify")
    public String PayNotify(HttpServletRequest request) {
        return wxPayService.PayNotify(request);


    }

    /**
     * 跳转中间页
     * @param userId
     * @param code
     * @param page
     * @return
     */
    @GetMapping("/page")
    public String chargePage(@RequestParam("userId") String userId, @RequestParam("code") String code,@RequestParam("state") String page) {


        return wxPayService.chargePage(userId, code,page);
    }

    /**
     * 查询订单
     * @param orderId
     * @return
     */
    @GetMapping("/query")
    public Result<OrderVo> queryOrder(@RequestParam("orderId") String orderId){
        return  Result.success(wxPayService.queryOrder(orderId));
    }

}
